# WildChat-50M Reproduction

This directory contains the training configuration to partially reproduce the results from the [WildChat-50M paper](https://arxiv.org/abs/2501.18511).

## Details

Training was done using the Oumi platform; following the paper, evaluation was done using [Evalchemy](https://github.com/mlfoundations/evalchemy/).

## Model

The checkpoint for the fully trained model, as well as the evaluation results and details about the training run, can be found on [HuggingFace](https://huggingface.co/penfever/oumi-l8b-ultrachat).
